==> imuikit-1.0.6.20180130_1T-sources.jar: com/xdja/im/common/cache/impl/ConfigCacheImpl.java <==
package com.xdja.im.common.cache.impl;

import android.support.annotation.Nullable;
import android.text.TextUtils;

import com.xdja.im.common.cache.entity.DeviceEntity;
import com.xdja.im.common.cache.entity.ServerEntity;
import com.xdja.im.common.cache.interf.ConfigCache;
import com.xdja.im.common.network.entity.ServerAddr;
import com.xdja.im.common.persistent.PropertyUtil;

import java.util.HashMap;
import java.util.Map;

import javax.inject.Inject;

/**
 * @Package:com.xdja.im.common.cache
 * @Author:Lei
 * @Creation:2017-04-11 22:15
 * @Version 1.0
 * @Description:配置信息缓存实现
 */
public class ConfigCacheImpl implements ConfigCache {

    public static final String PRONAME = "im_uikit_config.conf";

    public static final String DEVICE_TYPE = "deviceType";
    public static final String PLATFORM_TYPE = "platformType";
    public static final String EXT_TYPE = "extType";
    public static final String SERVER_IM_URL = "imUrl";
    public static final String SERVER_MX_URL = "mxUrl";
    public static final String SERVER_FASTDFS_ADDR = "fastDfsAddr";
    public static final String SERVER_FASTDFS_PORT = "fastDfsPort";

    public static final int DEFAULT_DEVICE_TYPE = 1; //默认设备类型：phone
    public static final int DEFAULT_PLATFORM_TYPE = 0; //默认平台类型：通用
    public static final int DEFAULT_EXT_TYPE = 0; //默认类型：OA

    private Map<String, String> configEntity;

    private DeviceEntity deviceEntity;

    private ServerEntity serverEntity;

    private PropertyUtil propertyUtil;

    @Inject
    public ConfigCacheImpl(PropertyUtil propertyUtil) {
        this.propertyUtil = propertyUtil;
        if (configEntity == null || configEntity.isEmpty()) {
            configEntity = this.get();
        }
        deviceEntity = new DeviceEntity();
        int deviceId = DEFAULT_DEVICE_TYPE;
        int platform = DEFAULT_PLATFORM_TYPE;
        int extType = DEFAULT_EXT_TYPE;
        try {
            deviceId = TextUtils.isEmpty(configEntity.get(DEVICE_TYPE)) ? 1 :
                    Integer.valueOf(configEntity.get(DEVICE_TYPE));
            platform = TextUtils.isEmpty(configEntity.get(PLATFORM_TYPE)) ? 0 :
                    Integer.valueOf(configEntity.get(PLATFORM_TYPE));
            extType = TextUtils.isEmpty(configEntity.get(EXT_TYPE)) ? 0 :
                    Integer.valueOf(configEntity.get(EXT_TYPE));
        } catch (Exception e) {
            e.printStackTrace();
        }
        deviceEntity.setDeviceType(deviceId);
        deviceEntity.setPlatformType(platform);
        deviceEntity.setExtType(extType);

        serverEntity = new ServerEntity();
        serverEntity.setImUrl(configEntity.get(SERVER_IM_URL));
        serverEntity.setMxUrl(configEntity.get(SERVER_MX_URL));

        ServerAddr serverAddr = new ServerAddr(
                configEntity.get(SERVER_FASTDFS_ADDR),
                configEntity.get(SERVER_FASTDFS_PORT)
        );
        serverEntity.setFastDfsUrl(serverAddr);
    }

    @Nullable
    @Override
    public Map<String, String> get() {
        configEntity = new HashMap<>();
        this.propertyUtil.load(PRONAME);
        this.configEntity = this.propertyUtil.getAll();
        return configEntity;
    }

    @Override
    public DeviceEntity getDevice() {
        return deviceEntity;
    }

    @Override
    public ServerEntity getServer() {
        return serverEntity;
    }
}

==> imuikit-1.0.9.20180609T-sources.jar: com/xdja/im/common/cache/impl/ConfigCacheImpl.java <==
package com.xdja.im.common.cache.impl;

import android.support.annotation.Nullable;
import android.text.TextUtils;

import com.xdja.im.common.cache.entity.DeviceEntity;
import com.xdja.im.common.cache.entity.ServerEntity;
import com.xdja.im.common.cache.interf.ConfigCache;
import com.xdja.im.common.network.entity.ServerAddr;
import com.xdja.im.common.persistent.PropertyUtil;

import java.util.HashMap;
import java.util.Map;

import javax.inject.Inject;

/**
 * @Package:com.xdja.im.common.cache
 * @Author:Lei
 * @Creation:2017-04-11 22:15
 * @Version 1.0
 * @Description:配置信息缓存实现
 */
public class ConfigCacheImpl implements ConfigCache {

    public static final String PRONAME = "im_uikit_config.conf";

    public static final String DEVICE_TYPE = "deviceType";
    public static final String PLATFORM_TYPE = "platformType";
    public static final String EXT_TYPE = "extType";
    public static final String HASFORWARD = "hasForward";
    public static final String SERVER_IM_URL = "imUrl";
    public static final String SERVER_MX_URL = "mxUrl";
    public static final String SERVER_USER_ID = "userid";
    public static final String SERVER_USER_SECRET = "usersecret";
    public static final String SERVER_FASTDFS_ADDR = "fastDfsAddr";
    public static final String SERVER_FASTDFS_PORT = "fastDfsPort";

    public static final int DEFAULT_DEVICE_TYPE = 1; //默认设备类型：phone
    public static final int DEFAULT_PLATFORM_TYPE = 0; //默认平台类型：通用
    public static final int DEFAULT_EXT_TYPE = 0; //默认类型：OA
    public static final int DEFAULT_HASFORWARD = 0; //默认类型：需要

    private Map<String, String> configEntity;

    private DeviceEntity deviceEntity;

    private ServerEntity serverEntity;

    private PropertyUtil propertyUtil;

    @Inject
    public ConfigCacheImpl(PropertyUtil propertyUtil) {
        this.propertyUtil = propertyUtil;
        if (configEntity == null || configEntity.isEmpty()) {
            configEntity = this.get();
        }
        deviceEntity = new DeviceEntity();
        int deviceId = DEFAULT_DEVICE_TYPE;
        int platform = DEFAULT_PLATFORM_TYPE;
        int extType = DEFAULT_EXT_TYPE;
        int hasForward = DEFAULT_HASFORWARD;
        try {
            deviceId = TextUtils.isEmpty(configEntity.get(DEVICE_TYPE)) ? 1 :
                    Integer.valueOf(configEntity.get(DEVICE_TYPE));
            platform = TextUtils.isEmpty(configEntity.get(PLATFORM_TYPE)) ? 0 :
                    Integer.valueOf(configEntity.get(PLATFORM_TYPE));
            extType = TextUtils.isEmpty(configEntity.get(EXT_TYPE)) ? 0 :
                    Integer.valueOf(configEntity.get(EXT_TYPE));
            hasForward = TextUtils.isEmpty(configEntity.get(HASFORWARD))? 0 :
                    Integer.valueOf(configEntity.get(HASFORWARD));
        } catch (Exception e) {
            e.printStackTrace();
        }
        deviceEntity.setDeviceType(deviceId);
        deviceEntity.setPlatformType(platform);
        deviceEntity.setExtType(extType);
        deviceEntity.setHasForward(hasForward);

        serverEntity = new ServerEntity();
        serverEntity.setImUrl(configEntity.get(SERVER_IM_URL));
        serverEntity.setMxUrl(configEntity.get(SERVER_MX_URL));
        serverEntity.setUserId(configEntity.get(SERVER_USER_ID));
        serverEntity.setUserSecret(configEntity.get(SERVER_USER_SECRET));
        ServerAddr serverAddr = new ServerAddr(
                configEntity.get(SERVER_FASTDFS_ADDR),
                configEntity.get(SERVER_FASTDFS_PORT)
        );
        serverEntity.setFastDfsUrl(serverAddr);
    }

    @Nullable
    @Override
    public Map<String, String> get() {
        configEntity = new HashMap<>();
        this.propertyUtil.load(PRONAME);
        this.configEntity = this.propertyUtil.getAll();
        return configEntity;
    }

    @Override
    public DeviceEntity getDevice() {
        return deviceEntity;
    }

    @Override
    public ServerEntity getServer() {
        return serverEntity;
    }
}
